@@ -19,10 +19,11 @@ from unittest.mock import MagicMock, Mock, NonCallableMagicMock, NonCallableMock
 import pytest
 from pytest import raises
 
-from hypothesis import given, strategies as st
+from hypothesis import assume, example, given, strategies as st
 from hypothesis.errors import HypothesisWarning
 from hypothesis.internal import reflection
 from hypothesis.internal.reflection import (
+    _lambda_source_key,
     convert_keyword_arguments,
     convert_positional_arguments,
     define_function_signature,
@@ -30,6 +31,7 @@ from hypothesis.internal.reflection import (
     get_pretty_function_description,
     get_signature,
     is_first_param_referenced_in_function,
+    is_identity_function,
     is_mock,
     proxies,
     repr_call,
@@ -548,29 +550,6 @@ def test_can_handle_unicode_identifier_in_same_line_as_lambda_def():
     assert get_pretty_function_description(is_str_pi) == "lambda x: x == pi"
 
 
-def test_can_render_lambda_with_no_encoding(monkeypatch):
-    is_positive = lambda x: x > 0
-
-    # Monkey-patching out the `detect_encoding` method here means
-    # that our reflection can't detect the encoding of the source file, and
-    # has to fall back to assuming it's ASCII.
-
-    monkeypatch.setattr(reflection, "detect_encoding", None)
-    assert get_pretty_function_description(is_positive) == "lambda x: x > 0"
-
-
-def test_does_not_crash_on_utf8_lambda_without_encoding(monkeypatch):
-    # Monkey-patching out the `detect_encoding` method here means
-    # that our reflection can't detect the encoding of the source file, and
-    # has to fall back to assuming it's ASCII.
-
-    monkeypatch.setattr(reflection, "detect_encoding", None)
-    # fmt: off
-    pi = "π"; is_str_pi = lambda x: x == pi  # noqa: E702
-    # fmt: on
-    assert get_pretty_function_description(is_str_pi) == "lambda x: <unknown>"
-
-
 def test_too_many_posargs_fails():
     with pytest.raises(TypeError):
         st.times(time.min, time.max, st.none(), st.none()).validate()
@@ -595,7 +574,6 @@ def test_inline_given_handles_self():
 def logged(f):
     @wraps(f)
     def wrapper(*a, **kw):
-        # print("I was called")
         return f(*a, **kw)
 
     return wrapper
@@ -710,3 +688,81 @@ def test_clean_source(src, clean):
 def test_overlong_repr_warns():
     with pytest.warns(HypothesisWarning, match="overly large"):
         repr(LazyStrategy(st.one_of, [st.none()] * 10000, {}))
+
+
+def identity(x):
+    return x
+
+
+class Identity:
+    def __call__(self, x):
+        return x
+
+    def instance_identity(self, x):
+        return x
+
+    def instance_self(self):
+        return self
+
+    @staticmethod
+    def static_identity(x):
+        return x
+
+    @classmethod
+    def class_identity(cls, x):
+        return x
+
+
+@pytest.mark.parametrize(
+    "f",
+    [
+        lambda x: x,
+        identity,
+        Identity(),
+        Identity().instance_identity,
+        Identity.static_identity,
+        Identity.class_identity,
+    ],
+)
+def test_is_identity(f):
+    assert is_identity_function(f)
+
+
+@example(Identity().instance_self)
+@example(lambda x, y: x)
+@example(lambda: None)
+@given(st.functions(like=identity, returns=st.from_type(type).flatmap(st.from_type)))
+def test_is_not_identity(f):
+    obj = object()
+    try:
+        assume(f(obj) is not obj)  # not necessary but ...
+    except TypeError:
+        pass
+    assert not is_identity_function(f)
+
+
+@pytest.mark.parametrize(
+    "f",
+    [
+        lambda x, y=None: x,  # this one would be fairly easy to recognize
+        lambda x, y=None: y or x,  # ... but the general case is impossible
+    ],
+)
+def test_is_unrecognized_identity(f):
+    assert not is_identity_function(f)
+
+
+def test_cache_key_size_is_bounded():
+    # Modify co_consts because ("a" * 1000) may not be evaluated at compile time
+    f = lambda: "a"
+    f.__code__ = f.__code__.replace(
+        co_consts=tuple(c * 1000 if c == "a" else c for c in f.__code__.co_consts)
+    )
+    assert len(repr(reflection._lambda_source_key(f))) > 1000
+    assert len(repr(reflection._lambda_source_key(f, bounded_size=True))) < 1000
+
+
+def test_lambda_source_key_distinguishes_alpha_renames():
+    # these terms are equivalent under the lambda calculus, but their
+    # representations are not, so they should be cached differently.
+    assert _lambda_source_key(lambda x: x) != _lambda_source_key(lambda y: y)
