@@ -575,7 +575,7 @@ PYTHONS = {
     "3.12": "3.12.11",
     "3.13": "3.13.5",
     "3.13t": "3.13t-dev",
-    "3.14": "3.14.0b3",
+    "3.14": "3.14.0rc1",
     "3.14t": "3.14t-dev",
     "3.15": "3.15-dev",
     "3.15t": "3.15t-dev",
@@ -651,6 +651,7 @@ standard_tox_task("py39-pandas12", py="3.9")
 for kind in ("cover", "nocover", "niche", "custom"):
     standard_tox_task(f"crosshair-{kind}")
 
+standard_tox_task("threading")
 standard_tox_task("py39-oldestnumpy", py="3.9")
 standard_tox_task("py39-oldparser", py="3.9")
 standard_tox_task("numpy-nightly", py="3.12")
